#!/usr/bin/perl
use Test::More qw(no_plan);

use_ok( 'RDF::Query' );

my $query	= new RDF::Query ( 'data/foaf.xrdf' );
isa_ok( $query, 'RDF::Query' );

{
	print "# (?var qname literal)\n";
	my @results	= $query->query( <<"END" );
		SELECT
			?person
		WHERE
			(?person foaf:name "Gregory Todd Williams")
		USING
			foaf FOR <http://xmlns.com/foaf/0.1/>
END
	is( scalar(@results), 1, 'got one result' );
	isa_ok( $results[0], 'ARRAY' );
	is( scalar(@{$results[0]}), 1, 'got one field' );
	isa_ok( $results[0][0], 'RDF::Core::Resource' );
	is( $results[0][0]->getLabel, 'http://kasei.us/about/foaf.xrdf#greg', 'got person uri' );
}

{
	print "# (?var qname quri)\n";
	my @results	= $query->query( <<"END" );
		SELECT
			?person
		WHERE
			(?person foaf:homepage <http://kasei.us/>)
		USING
			foaf FOR <http://xmlns.com/foaf/0.1/>
END
	is( scalar(@results), 1, 'got one result' );
	isa_ok( $results[0], 'ARRAY' );
	is( scalar(@{$results[0]}), 1, 'got one field' );
	isa_ok( $results[0][0], 'RDF::Core::Resource' );
	is( $results[0][0]->getLabel, 'http://kasei.us/about/foaf.xrdf#greg', 'got person uri' );
}

{
	print "# multiple namespaces\n";
	my @results	= $query->query( <<"END" );
		SELECT
			?title
		WHERE
			(?person foaf:name "Gregory Todd Williams")
			(?desc dc:creator ?person)
			(?desc dc:title ?title)
		USING
			foaf FOR <http://xmlns.com/foaf/0.1/>
			dc FOR <http://purl.org/dc/elements/1.1/>
END
	is( scalar(@results), 1, 'got one result' );
	isa_ok( $results[0], 'ARRAY' );
	is( scalar(@{$results[0]}), 1, 'got one field' );
	isa_ok( $results[0][0], 'RDF::Core::Literal' );
	is( $results[0][0]->getLabel, 'FOAF Description for Gregory Williams', 'got file title' );
}

{
	print "# chained (name->person->homepage)\n";
	my @results	= $query->query( <<"END" );
		SELECT
			?page
		WHERE
			(?person foaf:name "Gregory Todd Williams")
			(?person foaf:homepage ?page)
		USING
			foaf FOR <http://xmlns.com/foaf/0.1/>
END
	is( scalar(@results), 1, 'got one result' );
	isa_ok( $results[0], 'ARRAY' );
	is( scalar(@{$results[0]}), 1, 'got one field' );
	isa_ok( $results[0][0], 'RDF::Core::Resource' );
	is( $results[0][0]->getLabel, 'http://kasei.us/', 'got homepage url' );
}

{
	print "# chained (homepage->person->(name|mbox)\n";
	my @results	= $query->query( <<"END" );
		SELECT
			?name ?mbox
		WHERE
			(?person foaf:homepage <http://kasei.us/>)
			(?person foaf:name ?name)
			(?person foaf:mbox ?mbox)
		USING
			foaf FOR <http://xmlns.com/foaf/0.1/>
END
	is( scalar(@results), 1, 'got one result' );
	isa_ok( $results[0], 'ARRAY' );
	is( scalar(@{$results[0]}), 2, 'got two fields' );
	isa_ok( $results[0][0], 'RDF::Core::Literal' );
	isa_ok( $results[0][1], 'RDF::Core::Resource' );
	is( $results[0][0]->getLabel, 'Gregory Todd Williams', 'got name' );
	is( $results[0][1]->getLabel, 'mailto:greg@evilfunhouse.com', 'got mbox uri' );
}

